@@ -1,6 +1,6 @@
 from typing import Any, Tuple, Callable
 from pyspark.sql import SparkSession, DataFrame
-#from pyspark.dbutils import DBUtils
+from pyspark.dbutils import DBUtils
 import IPython as ip
 
 
@@ -29,15 +29,15 @@ def _get_spark() -> SparkSession:
             return spark
 
 
-# def _get_dbutils(spark: SparkSession):
-#     try:
-#         dbutils = DBUtils(spark)
-#     except ImportError:
-#         import IPython
-#         dbutils = IPython.get_ipython().user_ns.get("dbutils")
-#         if not dbutils:
-#             print("could not initialise dbutils!")
-#     return dbutils
+def _get_dbutils(spark: SparkSession):
+    try:
+        dbutils = DBUtils(spark)
+    except ImportError:
+        import IPython
+        dbutils = IPython.get_ipython().user_ns.get("dbutils")
+        if not dbutils:
+            print("could not initialise dbutils!")
+    return dbutils
 
 
 # initialise Spark variables
@@ -45,4 +45,4 @@ def _get_spark() -> SparkSession:
 #print(ipythontest)
 is_databricks: bool = _check_is_databricks()
 spark: SparkSession = _get_spark()
-#dbutils = _get_dbutils(spark)
+dbutils = _get_dbutils(spark)
